/*
 * Copyright 2016 - 2021 gary@drinkingtea.net
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

#include <imgui.h>

#include "projecttreemodel.hpp"

namespace nostalgia {

ProjectTreeModel::ProjectTreeModel(const ox::String &name,
                                   ox::Vector<ox::UniquePtr<ProjectTreeModel>> children) noexcept {
	m_name = name;
	m_children = std::move(children);
}

ProjectTreeModel::ProjectTreeModel(ProjectTreeModel &&other) noexcept {
	m_name = std::move(other.m_name);
	m_children = std::move(other.m_children);
}

void ProjectTreeModel::draw(core::Context *ctx) noexcept {
	constexpr auto dirFlags = ImGuiTreeNodeFlags_OpenOnArrow | ImGuiTreeNodeFlags_OpenOnDoubleClick;
	if (m_children.size()) {
		if (ImGui::TreeNodeEx(m_name.c_str(), dirFlags)) {
			for (auto &child : m_children) {
				child->draw(ctx);
			}
			ImGui::TreePop();
		}
	} else {
		if (ImGui::TreeNodeEx(m_name.c_str(), ImGuiTreeNodeFlags_Leaf)) {
			ImGui::TreePop();
		}
	}
}

}